%define major_ver %(echo %version | cut -d. -f1)
%define minor_ver %(echo %version | cut -d. -f2)

Summary:   International Components for Unicode
Name:      icu
Version:   75.1
Release:   1%{?dist}
License:   MIT and UCD and Public Domain
URL:       http://site.icu-project.org/
Source0:   https://github.com/unicode-org/icu/releases/download/release-%{major_ver}-%{minor_ver}/icu4c-%{major_ver}_%{minor_ver}-src.tgz


BuildRequires: gcc, gcc-c++, make, autoconf, python
Requires: libicu = %{version}-%{release}

%description
International Components for Unicode (ICU) is an open-source project of mature
C/C++ and Java libraries for Unicode support, software internationalization,
and software globalization. ICU is widely portable to many operating systems
and environments. It gives applications the same results on all platforms and
between C, C++, and Java software. The ICU project is a technical committee of
the Unicode Consortium and sponsored, supported, and used by IBM and many other
companies.

%package -n libicu
Summary: International Components for Unicode - libraries

%description -n libicu
This package contains the libraries.

%package  -n libicu-devel
Summary: International Components for Unicode - development files
Requires: pkgconfig
Requires: icu = %{version}-%{release}

%description -n libicu-devel
This package contains the development files.



%prep
%autosetup -p1 -n %{name}



%build
pushd source
autoconf
CFLAGS='%optflags -fno-strict-aliasing'
CXXFLAGS='%optflags -fno-strict-aliasing'
%configure \
    --with-data-packaging=library \
    --disable-samples \
    --enable-debug \
    --enable-tracing


sed -i 's|-nodefaultlibs -nostdlib||' config/mh-linux
sed -i 's| \$(docfilesdir)/installdox||' Makefile
sed -i '/^\s\+\$(INSTALL_DATA) \$(docsrchfiles) \$(DESTDIR)\$(docdir)\/\$(docsubsrchdir)\s*$/d' Makefile
test -f uconfig.h.prepend && sed -e '/^#define __UCONFIG_H__/ r uconfig.h.prepend' -i common/unicode/uconfig.h
sed -i -r 's|(PKGDATA_OPTS = )|\1-v |' data/Makefile

%make_build



%install
%make_install %{?_smp_mflags} -C source
chmod +x %{buildroot}%{_libdir}/*.so.*



%check
if grep -q @VERSION@ source/tools/*/*.8 source/tools/*/*.1 source/config/*.1; then
    exit 1
fi
%make_build -C source check



%files
%license license.html
%exclude %{_datadir}/%{name}/*/LICENSE
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man8/*.8*

%files -n libicu
%license LICENSE
%doc readme.html
%{_libdir}/*.so.*

%files -n libicu-devel
%license LICENSE
%doc source/samples/
%{_includedir}/unicode
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/%{version}
%{_datadir}/%{name}/%{version}/install-sh
%{_datadir}/%{name}/%{version}/mkinstalldirs
%{_datadir}/%{name}/%{version}/config



%changelog
* Fri Jul 19 2024 Upgrade Robot <upbot@opencloudos.tech> - 75.1-1
- Upgrade to version 75.1

* Sun Oct 8 2023 Shuo Wang <abushwang@tencent.com> - 73.2-4
- backport patch from upstream to fix test fail

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 73.2-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 73.2-2
- Rebuild.

* Thu Aug 03 2023 rockerzhu <rockerzhu@tencent.com> - 73.2-1
- Update to 73.2.

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 71.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 71.1-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Jul 01 2022 Zhao Zhen <jeremiazhao@tencent.com> - 71.1-1
- Initial Building.
